==> freifunk-openwrt-kit-1.6.37-ffgraz.tar.gz: www/cgi-bin-pre.sh <==
#!/bin/sh
echo Content-type: text/html
echo

cat<<EOF
<HTML>
<HEAD>
<TITLE>$(n=$(nvram get wan_hostname);echo ${n:-graz.funkfeuer.at}) - $TITLE</TITLE>
<META CONTENT="text/html; charset=iso-8859-1" HTTP-EQUIV="Content-Type">
<META CONTENT="no-cache" HTTP-EQUIV="cache-control">
<LINK HREF="ffgraz.css" REL="StyleSheet" TYPE="text/css">
<LINK HREF="sven-ola*t*gmx*de" REV="made" TITLE="Sven-Ola">
<STYLE TYPE="text/css">
$(if ! grep -q '^LoadPlugin "olsrd_nameservice.so' /etc/olsrd.conf 2>&-;then echo '.plugin-services {display:none}';echo '.plugin-map {display:none}';elif test -z "`nvram get ff_adm_latlon`";then echo '.plugin-map {display:none}';fi)
</STYLE>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript"><!--
function help(e) {
if (!e) e = event;
// (virt)KeyVal is Konqueror, charCode is Moz/Firefox, else MSIE, Netscape, Opera
if (26 == e.virtKeyVal || !e.keyVal && !e.charCode && 112 == (e.which || e.keyCode)) {
var o = null;
if (e.preventDefault) {
if (e.cancelable) e.preventDefault();
o = e.target;
}
else {
e.cancelBubble = true;
o = e.srcElement;
}
while(o && '' == o.title) o = o.parentNode;
if (o) alert(o.title);
}
}
if (document.all) {
document.onkeydown = help;
document.onhelp = function(){return false;}
}
else {
document.onkeypress = help;
}
//--></SCRIPT>
</HEAD>
<BODY>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" CLASS="body">
<TR HEIGHT="51">
<TD VALIGN="top" CLASS="color">
<SPAN CLASS="color"><A CLASS="color" HREF="cgi-bin-index.html">Home</A></SPAN>
<IMG ALT="" HEIGHT="10" HSPACE="2" SRC="images/vertbar.gif" WIDTH="1">
<SPAN CLASS="color"><A CLASS="color" HREF="cgi-bin-admin.html">Verwalten</A></SPAN>
</TD>
<TD COLSPAN="2" ALIGN="right">
<A HREF="http://graz.funkfeuer.at/"><IMG ALT="" BORDER="0" SRC="images/ffgraz-logo.png"></A>
</TD>
</TR>
<TR CLASS="infoline">
<TD  HEIGHT="19">&nbsp;v1.6.37</TD>
<TD COLSPAN="2" HEIGHT="19" ALIGN="RIGHT">
<ADDRESS CLASS="infoline">
Stand
: $DATE
</ADDRESS>
</TD>
</TR>
<TR>
<TD HEIGHT="5" WIDTH="150"></TD>
<TD HEIGHT="5"></TD>
<TD CLASS="color" HEIGHT="5" ROWSPAN="2" VALIGN="top" WIDTH="150">
</TD>
</TR>
<TR>
<TD CLASS="color" VALIGN="top" WIDTH="150">
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="7" WIDTH="150">
<TR>
<TD><BIG CLASS="plugin">
Inhalt
</BIG></TD>
</TR>
EOF

for inc in /www/[0-9][0-9]-*;do test -n "${inc##*.sh}" && cat $inc ||. $inc;done

cat<<EOF
</TABLE></TD>
<TD VALIGN="top">
EOF

==> freifunk-openwrt-kit-1.7.4-ffgraz.tar.gz: www/cgi-bin-pre.sh <==
#!/bin/sh
echo Content-type: text/html
echo

cat<<EOF
<HTML>
<HEAD>
<TITLE>$(n=$(nvram get wan_hostname);echo ${n:-graz.funkfeuer.at}) - $TITLE</TITLE>
<META CONTENT="text/html; charset=iso-8859-1" HTTP-EQUIV="Content-Type">
<META CONTENT="no-cache" HTTP-EQUIV="cache-control">
<LINK HREF="ffgraz.css" REL="StyleSheet" TYPE="text/css">
<LINK HREF="sven-ola*t*gmx*de" REV="made" TITLE="Sven-Ola">
<STYLE TYPE="text/css">
$(if ! grep -q '^LoadPlugin "olsrd_nameservice.so' /etc/olsrd.conf 2>&-;then echo '.plugin-services {display:none}';echo '.plugin-map {display:none}';elif test -z "`nvram get ff_adm_latlon`";then echo '.plugin-map {display:none}';fi)
</STYLE>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript"><!--
function help(e) {
if (!e) e = event;
// (virt)KeyVal is Konqueror, charCode is Moz/Firefox, else MSIE, Netscape, Opera
if (26 == e.virtKeyVal || !e.keyVal && !e.charCode && 112 == (e.which || e.keyCode)) {
var o = null;
if (e.preventDefault) {
if (e.cancelable) e.preventDefault();
o = e.target;
}
else {
e.cancelBubble = true;
o = e.srcElement;
}
while(o && '' == o.title) o = o.parentNode;
if (o) alert(o.title);
}
}
if (document.all) {
document.onkeydown = help;
document.onhelp = function(){return false;}
}
else {
document.onkeypress = help;
}
//--></SCRIPT>
</HEAD>
<BODY>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" CLASS="body">
<TR HEIGHT="51">
<TD VALIGN="top" CLASS="color">
<SPAN CLASS="color"><A CLASS="color" HREF="cgi-bin-index.html">Home</A></SPAN>
<IMG ALT="" HEIGHT="10" HSPACE="2" SRC="images/vertbar.gif" WIDTH="1">
<SPAN CLASS="color"><A CLASS="color" HREF="cgi-bin-admin.html">Verwalten</A></SPAN>
</TD>
<TD COLSPAN="2" ALIGN="right">
<A HREF="http://graz.funkfeuer.at/"><IMG ALT="" BORDER="0" SRC="images/ffgraz-logo.png"></A>
</TD>
</TR>
<TR CLASS="infoline">
<TD  HEIGHT="19">&nbsp;v1.7.4<!--%FFVER%--></TD>
<TD COLSPAN="2" HEIGHT="19" ALIGN="RIGHT">
<ADDRESS CLASS="infoline">
Stand
: $DATE
</ADDRESS>
</TD>
</TR>
<TR>
<TD HEIGHT="5" WIDTH="150"></TD>
<TD HEIGHT="5"></TD>
<TD CLASS="color" HEIGHT="5" ROWSPAN="2" VALIGN="top" WIDTH="150">
</TD>
</TR>
<TR>
<TD CLASS="color" VALIGN="top" WIDTH="150">
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="7" WIDTH="150">
<TR>
<TD><BIG CLASS="plugin">
Inhalt
</BIG></TD>
</TR>
EOF

for inc in /www/[0-9][0-9]-*;do case ${inc##*.sh} in ""). $inc;;*)cat $inc;;esac;done

cat<<EOF
</TABLE></TD>
<TD VALIGN="top">
EOF
